Stan Math Library: stan/math/rev/core/operator_unary_decrement.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

operator_unary_decrement.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_CORE_OPERATOR_UNARY_DECREMENT_HPP
2 #define STAN_MATH_REV_CORE_OPERATOR_UNARY_DECREMENT_HPP
3
4 #include <stan/math/rev/core/var.hpp>
5 #include <stan/math/rev/core/v_vari.hpp>
6 #include <boost/math/special_functions/fpclassify.hpp>
7 #include <limits>
8
9 namespace stan {
10 namespace math {
11
12 namespace {
13 class decrement_vari : public op_v_vari {
14 public:
15 explicit decrement_vari(vari* avi) :
16 op_v_vari(avi->val_ - 1.0, avi) {
17 }
18 void chain() {
19 if (unlikely(boost::math::isnan(avi_->val_)))
20 avi_->adj_ = std::numeric_limits<double>::quiet_NaN();
21 else
22 avi_->adj_ += adj_;
23 }
24 };
25 }
26
40 inline var& operator--(var& a) {
41 a.vi_ = new decrement_vari(a.vi_);
42 return a;
43 }
44
56 inline var operator--(var& a, int /*dummy*/) {
57 var temp(a);
58 a.vi_ = new decrement_vari(a.vi_);
59 return temp;
60 }
61
62 }
63 }
64 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
stan::math::operator--
var & operator--(var &a)
Prefix decrement operator for variables (C++).
Definition: operator_unary_decrement.hpp:40
boost::math::isnan
bool isnan(const stan::math::var &v)
Checks if the given number is NaN.
Definition: boost_isnan.hpp:22
unlikely
#define unlikely(x)
Definition: likely.hpp:9
v_vari.hpp
stan::math::var::vi_
vari * vi_
Pointer to the implementation of this variable.
Definition: var.hpp:43
var.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.